@@ -36,6 +36,9 @@ private slots:
 	void setIconSet2();
 	void setIconSet3();
 	void setIconSet4();
+	void setDailyMode();
+	void setSearchMode();
+	void setCurrentMode();
 	void setIconSet(QString iconset);
 	void cancel();
 	void save();
